#! /usr/bin/env bash

# Environment variables:
# - CTF_SUB_FILES
# - CTF_SUB_DIR
# - CTF_WORKDIR
# - CTF_TRACES_TRAIN_DIR
#   Top-level directory containing the training sets (shall be set to the
#   top-level public set during the envaluation, that is, the directory
#   containing sw3/, sw4/, etc.)
# - CTF_CHALLENGE_DIR
#   Top-level directory containing the traces to attack. Shall have identical
#   structure to the $CTF_TRACES_TRAIN_DIR.
#   The user running this script must have read and write access to all the
#   files in this directory.
# - CTF_CHALLENGE_TMP
#   Temporary directory to store temporary challenge traces. This directory
#   contains hardlinks to files in CTF_CHALLENGE_DIR, hence must be on the same
#   partition.
# - CTF_N_ATTACK_SETS
#   Number of different keys on which the attack should be run (goes from key_O to key.
# - CTF_SUDO_RESOURCES
#   Set to 1 to limit resources (CPU, RAM) usage. Requires sudo rights.

ACTION=$1

SCRIPT=$(readlink -f $0)
export SCRIPTPATH=`dirname $SCRIPT`

IFS=$'\n' read -d '' -r -a submission_files < $CTF_SUB_FILES

for submission_file in "${submission_files[@]}"
do
    SUB_NAME=$(echo $submission_file | cut -d '.' -f 1)
    export CTF_SUB_FILE=$CTF_SUB_DIR/$submission_file
    export CTF_BASE_DIR=$CTF_WORKDIR/submissions/$SUB_NAME
    mkdir -p $CTF_BASE_DIR
    case $ACTION in
    unpack)
        echo "Unpacking $SUB_NAME..."
        $SCRIPTPATH/main.sh unpack
        echo "Finished unpacking"
        ;;
    setup|profile|attack|rank)
        stage=$ACTION
        DUMP_DIR=$CTF_WORKDIR/cmd_$stage
        mkdir -p $DUMP_DIR
        CTF_DUMP_CMD=1 CTF_DUMP_PREFIX=$DUMP_DIR/$SUB_NAME $SCRIPTPATH/main.sh $stage
        ;;
    summarize_ranks)
        $SCRIPTPATH/main.sh summarize_ranks
        ;;
    *)
        echo "Unkown command $ACTION. Supported commands: unpack, setup, profile, attack."
    esac
done

